import { scaleLinear } from 'd3';
import { AxisBottom } from './AxisBottom';
import { AxisLeft } from './AxisLeft';

const svgWidth = 950
const svgHeight = 450
const margin = { top: 20, right: 20, bottom: 20, left: 50 }
const delay = 5

export const Scatter = ({data}) => {
  
  if (!data) {
    return <pre>Loading...</pre>
  }

  const chartWidth = svgWidth - margin.left - margin.right
  const chartHeight = svgHeight - margin.top - margin.bottom

  const yScale = scaleLinear().range([chartHeight, 0]).domain([0, d3.max(data, d => +d.a)])
  const xScale = scaleLinear().range([0, chartWidth]).domain([0, d3.max(data, d => +d.n)])

  return (
    <svg width={svgWidth} height={svgHeight}>
      <g transform={`translate(${margin.left},${margin.top})`}>
        
        <AxisLeft
          yScale={yScale}
          chartHeight={chartHeight}
          chartWidth={chartWidth}
          tickWidth={5}
        />
        
        <AxisBottom
          xScale={xScale}
          chartHeight={chartHeight}
          chartWidth={chartWidth}
          tickWidth={5}
        />
      </g>
    </svg>
  );
};
